
API_URL = "https://test-packapi.protectremote.com/rules"
REQUEST_INTERVAL_IN_SECONDS=15
DEBUG_MODE_IP_ADDRESS = ""
DEBUG_MODE=False
RENDER_HTML_PAGE=True
TOKEN = ""
RESTRICTED_MESSAGE = "PROTECT_REMOTE_ACCESS_DENIED"
RULES_DATA= []